@@ -581,135 +581,6 @@ WW[̃t@C /Perl/site/lib/Sjis ɃRs[ 'use utf8;'
    warnings.pm_  warnings.pm ɁAwarnings/register.pm_ 
   warnings/register.pm Ƀt@CύXĎgpł܂B
 
-  perl5.005 𗘗pĂۂ Perl5.6 ̊֐̓G~[g܂B
-
-  --------------------------------------------------------------------
-  O                           Esjis.pm  BEGIN { } Őݒ
-  --------------------------------------------------------------------
-  binmode(...);   Esjis::binmode(...);   *CORE::GLOBAL::binmode = ...
-  open(...);      Esjis::open(...);      *CORE::GLOBAL::open    = ...
-  --------------------------------------------------------------------
-
-=over 2
-
-=item * binmode (perl5.005 ɂ Perl5.6 G~[V)
-
-  binmode(FILEHANDLE, $disciplines);
-  binmode(FILEHANDLE);
-  binmode($filehandle, $disciplines);
-  binmode($filehandle);
-
-  * 2 ̈g܂
-
-   MacPerl ȊO perl5.005 Ŏsꍇ́APerl5.6  binmode ֐̋@\G
-  ~[g܂Bȉ͗v_݂̂̋LqȂ̂ŁAڍׂ perlfunc/binmode QƂ
-  B
-
-   t@Cnh FILEHANDLE ɑ΂āA$disciplines Ŏw肳ꂽs
-  ɂB$disciplines ȗƁAt@Cnh ':raw' ƂĈ悤
-  BFILEHANDLE ꍇA̒lt@Cnh̖O܂̓t@Cn
-  hւ̃t@XƂĈB
-
-   binmode ֐́At@C open ĂÃt@Cnhɑ΂Ďۂ I/O
-  s܂ł̊ԂɁAsȂ΂ȂȂB܂܂ȃ[hAobt@̂
-  ܂܂ȃf[^ɑ΂āA܂܂ȉHs߂ɁAt@C̃[hZbg
-  ɂ́Ãt@CI[vȂȊOɕ@͂ȂB
-
-   ":raw" fBVv́APerl f[^̒gɎoȂ悤ɂ邽߂̂̂ł
-  BefBVvǂ̂悤ɓ삷邩ɂĂ open ֐̍QƂĂ
-  B
-
-=item * open (perl5.005 ɂ Perl5.6 G~[V)
-
-  open(FILEHANDLE, $mode, @list);
-  open(FILEHANDLE, $expr);
-  open(FILEHANDLE);
-  open(my $filehandle, $mode, @list);
-  open(my $filehandle, $expr);
-  open(my $filehandle);
-
-  * t@Cnh(autovivification)܂
-  * 3 ̈g܂
-
-  perl5.005 Ŏsꍇ́APerl5.6  open ֐̋@\G~[g܂B
-  ȉ͗v_݂̂̋LqȂ̂ŁAڍׂ perlfunc/open QƂĂB
-
-   ̗Ⴊ悤ɁAĂ̏ꍇAFILEHANDLE ͒PȎʎq(ʂ͑啶
-  ݂̂琬)ł邪A̒lt@Cnhւ̃t@XɂȂ悤Ȏ
-  w肷邱ƂłB(̃t@Xɂ́At@Cnhɑ΂V{
-  bNt@XA܂̓t@CnhƉ߂łCӂ̃IuWFNgւ
-  n[ht@XwłB)͊Ԑڃt@Cnh(indirect filehandle)
-  ƌĂ΂B1Ƃ FILEHANDLE 󂯎邷ׂĂ̊֐́At@Cnh
-  ̑ɁAԐڃt@Cnh󂯎邱ƂłB open ̏ꍇ͓
-  ŁAԐڃt@CnhƂĖ`̕ϐw肷ƁAPerl ͎Iɂ̕ϐ
-  `āAɂāAK؂ȃt@Cnhւ̃t@XZbg
-  B̗_1ƂẮAt@CnhǂQƂȂȂ(T^
-  Iɂ́A̕ϐ̃XR[v甲oꍇ)ƁAIɃN[YƂ
-  B
-
-  {
-      my $fh;                   # (ĂȂ)
-      open($fh, ">logfile")     # $fh ͎
-          or die "Can't create logfile: $!";
-          ...                   # $fh gďs
-  }                             # $fh ͂ŃN[Y
-
-  ܂Â悤ɂāAopen ֐Ăяoۂ my $fh 錾s΁Aɓǂ݂₷
-  Ȃ:
-
-  open my $fh, ">logfile" or die ...
-
-   ŁAt@C̐擪ɂ ">" ́A[ḧłBjIȘbƁA
-  ɗpӂꂽ open 2̂̂łBŋ߁Aꂽ3 open ł́A[
-  ht@CƗĕʌɎwł̂ŁA炪邱ƂȂƂ
-  _BႦ΁AɎR[hł́A">" Ŏn܂閼Ot@CI[v
-  킯ł͂ȂƂ킩B̃R[hł́A$mode Ƃ ">" w肳Ă
-  ŁA$expr Ŏw肳ꂽOt@CݗpɃI[v悤ƂB
-  ̍ۂɁAt@C݂ȂΐVɍ쐬AłɃt@C݂΁A
-  ̃t@C؂̂Ăċɂ:
-  
-  open(LOG, ">", "logfile")  or die "Can't create logfile: $!";
-
-   12 open ł́Aϐt@CƂĎgۂɂ͒ӂKvłB
-  ȂȂAϐ͓̂̒mȂ镶܂ł\邩炾(ɁAC
-  ^[lbg̓̂̒mȂ[Ut@C󂯎ꍇ)B\ɒӂȂ
-  ƁAt@C̈ꕔA$mode A󔒕Adup wq(>& Ȃ)A
-  }CiX "-" Ɖ߂Ă܂\BɎ̂́Ãgu邽
-  ߂ɁA`IɍsĂ1łB
-
-  $path =~ s#^([ ])#./$1#;
-  open (FH, "< $path\0") or die "can't open $path: $!";
-
-   Aɂ܂肪BɁA3 open g悤ɂ
-  ΁AZLeB̃XNɂ炳ꂸɁACӂ̃t@CAN[Ɉ
-  ł:
-
-  open(FH, "<", $path) or die "can't open $path: $!";
-
-   ܂APerl ̃[X 5.6 ł́Aopen ֐ŃoCi[hwł悤ɂȂ
-  Ă̂ŁA킴킴 binmode ֐ʂɌĂяoɍςށB$mode ̈ꕔƂāA
-  X̓̓fBVvƏo̓fBVvw肷邱Ƃł(3̏ꍇ̂)B
-  binmode ƓȂƂɂ́A3 open gāA $mode ̌
-  :raw fBVvw肷΂悢:
-
-  open(FH, "<:raw", $path) or die "can't open $path: $!";
-
-  \ 1. I/O fBVv
-  ---------------------------------------------------
-  fBVv    Ӗ
-  ---------------------------------------------------
-  :raw            oCi[hAȂ
-  :crlf           s𔻕ʂ(DOSOS̏ꍇ)
-  :encoding(...)  GR[fBOw肷
-  ---------------------------------------------------
-
-   (邱ƂɈӖȂ)fBVvςݏd˂邱ƂłBႦ΁A
-  ̂悤Ȏw\ł:
-
-  open(FH, "<:crlf:encoding(Sjis)", $path) or die "can't open $path: $!";
-
-=back
-
 =head1 vO}уW[
 
   -----------------------------------------------------------
@@ -1760,6 +1631,18 @@ vO~O񋟂܂B
  346y[W
  ISBN 4-7561-0963-2
 
+ J E, ۉK\CuȂ
+ http://lc.linux.or.jp/lc2001/papers/dfa-i18n-paper.pdf
+ http://lc.linux.or.jp/lc2002/papers/hasegawa0918h.pdf
+ http://lc.linux.or.jp/lc2002/papers/hasegawa0918p.pdf
+ http://www.j-tokkyo.com/2003/G06F/JP2003-242179.shtml
+
+ Oc א, }`oCgZbgpK\RpC\@yуvO 
+ http://patent.astamuse.com/ja/published/JP/No/2007102744
+
+ YAMAGAKI Norio, }`oCgƍpLI[g}gVXe
+ http://www.wipo.int/pctdb/ja/wo.jsp?WO=2009116646&IA=JP2009055515
+
  ֘A\tgEFA
  http://search.cpan.org/dist/jacode/
  http://search.cpan.org/dist/Char/
